| Home | Libraries | People | FAQ | More

### is_const

    template <class T>
    struct is_const : public true_type-or-false_type {};

Inherits: If T is a (top level) const-qualified type then inherits from true_type, otherwise inherits from false_type.

C++ Standard Reference: 3.9.3.

Header: `#include <boost/type_traits/is_const.hpp>` or `#include <boost/type_traits.hpp>`

Compiler Compatibility: All current compilers are supported by this trait.

Examples:

> `is_const<int const>` inherits from `true_type`.

> `is_const<int const volatile>::type` is the type `true_type`.

> `is_const<int* const>::value` is an integral constant expression that evaluates to true.

> `is_const<int const*>::value` is an integral constant expression that evaluates to false: the const-qualifier is not at the top level in this case.

> `is_const<int const&>::value` is an integral constant expression that evaluates to false: the const-qualifier is not at the top level in this case.

> `is_const<int>::value` is an integral constant expression that evaluates to false.

> `is_const<T>::value_type` is the type `bool`.